@@ -858,6 +858,16 @@ def main(md_origin, origin_type="file", website_root=None, destination=None, ima
 
         if DEBUG:
             print("dict of image hashes:", hashes_to_images)
+    else:
+        # if image caching is disabled, change image's `src` to their `data-canonical-src` to revert GitHub's caching.
+        html_soup = BeautifulSoup(html_rendered, 'html.parser')
+        for img_soup_representation in html_soup.find_all("img"):
+            if img_soup_representation.has_attr("data-canonical-src"):
+                if (img_soup_representation.parent.has_attr("href")
+                        and img_soup_representation.parent["href"] == img_soup_representation["src"]):
+                    img_soup_representation.parent["href"] = img_soup_representation["data-canonical-src"]
+                img_soup_representation["src"] = img_soup_representation["data-canonical-src"]
+        html_rendered = html_soup.__str__()
 
     if DEBUG:
         print("\n------------\nHtml with image links:\n------------\n\n", html_rendered)
@@ -881,10 +891,23 @@ def main(md_origin, origin_type="file", website_root=None, destination=None, ima
     #       link_within_header.append(BeautifulSoup(GITHUB_LINK_ANCHOR, 'html.parser').find("svg"))
     html_rendered = html_soup.__str__()
 
+    # turns out to not be necessary (
+    # un-escape all `href`s und `src`s (they are all html-escaped, for some reason):
+    # html_soup = BeautifulSoup(html_rendered, 'html.parser')
+    # for tag in ("a", "img"):
+    #     for link_or_img_soup_representation in html_soup.find_all(tag):
+    #         for attr_name in ("src", "href", "data-canonical-src"):
+    #             if link_or_img_soup_representation.has_attr(attr_name):
+    #                 print("FOO&amp;Bar", link_or_img_soup_representation[attr_name][10:],
+    #                       html.unescape(link_or_img_soup_representation[attr_name])[10:])
+    #                 link_or_img_soup_representation[attr_name] = html.unescape(
+    #                     link_or_img_soup_representation[attr_name])
+    # html_rendered = html_soup.__str__()
+
     if DEBUG:
         print("\n------------\nHtml with fixed internal links:\n------------\n\n", html_rendered)
 
-    # ensure we have the css and the code navigation banner where we want it to be:
+    # ensure we have the css and the code navigation banner where we want it to be (anyone knows what this is for?):
     with open_local("github-css.min.css", "r") as from_f:
         with open(os.path.join(abs_css_paths, "github-css.css"), "w") as to_f:
             to_f.write(from_f.read())
@@ -910,21 +933,36 @@ def main(md_origin, origin_type="file", website_root=None, destination=None, ima
             raise Exception("""\
 Unfortunately, you need to have pdfkit installed to save as pdf. Find out how to install it here:
 https://pypi.org/project/pdfkit/""")
-        # ensure the image links are absolute file paths:
+        # ensure the image srcs are absolute file paths:
         # ToDo: Completely disable pdf conversion on windows machines, since wkhtmltopdf won't run on them anyways.
-        html_soup_representation = BeautifulSoup(html_rendered, parser="html.parser")
-        for link_type in ("src", "href"):
-            tags_with_links = html_soup_representation.find_all(lambda tag: tag.has_attr(link_type))
-            for tag_with_link in tags_with_links:
-                link = tag_with_link[link_type]
-                if link.startswith("https://") or link.startswith("http://"):
-                    pass
-                else:
-                    directory_to_link_to = abs_website_root if link.startswith("/") else abs_destination
-                    abs_path = urllib.parse.quote(os.path.join(os.getcwd(), directory_to_link_to.lstrip("/"), link))
-                    tag_with_link[link_type] = "file://" + abs_path
+        html_soup_representation = BeautifulSoup(html_rendered, "html.parser")
+        tags_with_links = html_soup_representation.find_all(lambda tag: tag.has_attr("src"))
+        for tag_with_link in tags_with_links:
+            link = tag_with_link["src"]
+            if link.startswith("https://") or link.startswith("http://"):
+                pass
+            else:
+                directory_to_link_to = abs_website_root if link.startswith("/") else abs_destination
+                abs_path = urllib.parse.quote(os.path.join(os.getcwd(), directory_to_link_to.lstrip("/"), link))
+                tag_with_link["src"] = "file://" + abs_path
         html_rendered = html_soup_representation.__str__()
 
+        # Remove links that link to something that clearly lies on the disk or is a relative link, since these won't
+        #  work in a pdf-file anyways or cannot be relied on.
+        html_soup_representation = BeautifulSoup(html_rendered, "html.parser")
+        for link in html_soup_representation.find_all("a"):
+            href = link["href"]
+            if (
+                    (href.startswith("/") and not href.startswith("//"))
+                    or href.startswith("file://")
+                    or (not href.startswith("/") and not href.startswith("#") and "://" not in href)
+            ):
+                for child in link:
+                    link.parent.append(child)
+                link.decompose()
+        html_rendered = html_soup_representation.__str__()
+        # ToDo: Make sure that anchor links work correctly... but that's a task for another day.
+
         # remove the css if we want to save it without css:
         if not style_pdf:
             html_rendered = "\n".join(html_rendered.split("\n")[2:])
@@ -1039,7 +1077,8 @@ if __name__ == "__main__":
     """)
 
     parser.add_argument('-f', '--footer', nargs="+", action=FuseInputString, help="""
-    An optional piece of html which will be included as a footer where the 'hosted with <3 by github'-footer usually is.
+    An optional piece of html which will be included as a footer where the 'hosted with <3 by github'-footer in a gist
+    usually is.
     Defaults to None, meaning that the section usually containing said footer will be omitted altogether.
     """)
 
@@ -1068,7 +1107,7 @@ if __name__ == "__main__":
     parser.add_argument('-o', '--core-converter', nargs="+", action=FuseInputString,
                         default=markdown_to_html_via_github_api, help="""
     The converter to use to convert the given markdown to html, before additional modifications such as formula support
-    and image downloading are applied; this can be
+    and image downloading are applied; this defaults to using GitHub's REST API and can be
     * on Unix/ any system with a cmd: a command containing the string "{md}", where "{md}" will be replaced with an
       escaped version of the markdown file's content, and which returns the finished html. Please note that commands for
       Unix-system won't work on Windows systems, and vice versa etc.
